==> centreon-web-25.09.2.tar.gz: centreon-web-25.09.2/src/Core/Infrastructure/Configuration/NotificationPolicy/Api/Hypermedia/ContactGroupHypermediaCreator.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Infrastructure\Configuration\NotificationPolicy\Api\Hypermedia;

use Centreon\Domain\Contact\Contact;
use Centreon\Domain\Contact\Interfaces\ContactInterface;
use Core\Infrastructure\Common\Api\HttpUrlTrait;

class ContactGroupHypermediaCreator
{
    use HttpUrlTrait;
    private const URI_CONFIGURATION_CONTACT_GROUP = '/main.php?p=60302&o=c&cg_id={contactGroupId}';

    /**
     * @param ContactInterface $contact
     */
    public function __construct(
        private ContactInterface $contact
    ) {
    }

    /**
     * Create the configuration URI to the contact group regarding ACL.
     *
     * @param int $contactGroupId
     *
     * @return string|null
     */
    public function createContactGroupConfigurationUri(int $contactGroupId): ?string
    {
        return (
            $this->contact->hasTopologyRole(Contact::ROLE_CONFIGURATION_SERVICES_SERVICE_GROUPS_READ_WRITE)
            || $this->contact->hasTopologyRole(Contact::ROLE_CONFIGURATION_SERVICES_SERVICE_GROUPS_READ)
            || $this->contact->isAdmin()
        )
        ? $this->getBaseUri()
            . str_replace('{contactGroupId}', (string) $contactGroupId, self::URI_CONFIGURATION_CONTACT_GROUP)
        : null;
    }
}

==> centreon-web-25.10.7.tar.gz: centreon-web-25.10.7/src/Core/Infrastructure/Configuration/NotificationPolicy/Api/Hypermedia/ContactGroupHypermediaCreator.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Infrastructure\Configuration\NotificationPolicy\Api\Hypermedia;

use Centreon\Domain\Contact\Contact;
use Centreon\Domain\Contact\Interfaces\ContactInterface;
use Core\Infrastructure\Common\Api\HttpUrlTrait;

class ContactGroupHypermediaCreator
{
    use HttpUrlTrait;
    private const URI_CONFIGURATION_CONTACT_GROUP = '/main.php?p=60302&o=c&cg_id={contactGroupId}';

    /**
     * @param ContactInterface $contact
     */
    public function __construct(
        private ContactInterface $contact,
    ) {
    }

    /**
     * Create the configuration URI to the contact group regarding ACL.
     *
     * @param int $contactGroupId
     *
     * @return string|null
     */
    public function createContactGroupConfigurationUri(int $contactGroupId): ?string
    {
        return (
            $this->contact->hasTopologyRole(Contact::ROLE_CONFIGURATION_SERVICES_SERVICE_GROUPS_READ_WRITE)
            || $this->contact->hasTopologyRole(Contact::ROLE_CONFIGURATION_SERVICES_SERVICE_GROUPS_READ)
            || $this->contact->isAdmin()
        )
        ? $this->getBaseUri()
            . str_replace('{contactGroupId}', (string) $contactGroupId, self::URI_CONFIGURATION_CONTACT_GROUP)
        : null;
    }
}
